==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/statemachine/impl/TransitionSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.statemachine.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.instance.I_INSSet;
import io.ciera.tool.sql.ooaofooa.instance.impl.I_INSSetImpl;
import io.ciera.tool.sql.ooaofooa.statemachine.CreationTransitionSet;
import io.ciera.tool.sql.ooaofooa.statemachine.MealyActionHomeSet;
import io.ciera.tool.sql.ooaofooa.statemachine.NewStateTransitionSet;
import io.ciera.tool.sql.ooaofooa.statemachine.NoEventTransitionSet;
import io.ciera.tool.sql.ooaofooa.statemachine.SM_SMSet;
import io.ciera.tool.sql.ooaofooa.statemachine.StateMachineStateSet;
import io.ciera.tool.sql.ooaofooa.statemachine.Transition;
import io.ciera.tool.sql.ooaofooa.statemachine.TransitionActionHomeSet;
import io.ciera.tool.sql.ooaofooa.statemachine.TransitionSet;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.CreationTransitionSetImpl;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.MealyActionHomeSetImpl;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.NewStateTransitionSetImpl;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.NoEventTransitionSetImpl;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.SM_SMSetImpl;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.StateMachineStateSetImpl;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.TransitionActionHomeSetImpl;

import java.util.Arrays;
import java.util.List;


public class TransitionSetImpl extends InstanceSet<TransitionSet,Transition> implements TransitionSet {

    // attributes
    @Override
    public void setSMstt_ID( UniqueId ref_SMstt_ID ) throws XtumlException {
        for ( Transition transition : this ) transition.setSMstt_ID( ref_SMstt_ID );
    }
    @Override
    public void setSMspd_IDdeprecated( UniqueId m_SMspd_IDdeprecated ) throws XtumlException {
        for ( Transition transition : this ) transition.setSMspd_IDdeprecated( m_SMspd_IDdeprecated );
    }
    @Override
    public void setTrans_ID( UniqueId m_Trans_ID ) throws XtumlException {
        for ( Transition transition : this ) transition.setTrans_ID( m_Trans_ID );
    }
    @Override
    public void setSM_ID( UniqueId ref_SM_ID ) throws XtumlException {
        for ( Transition transition : this ) transition.setSM_ID( ref_SM_ID );
    }


    // selections
    @Override
    public I_INSSet R2953_caused_last_state_change_to_I_INS() throws XtumlException {
        I_INSSet i_insset = new I_INSSetImpl();
        for ( Transition transition : this ) i_insset.addAll( transition.R2953_caused_last_state_change_to_I_INS() );
        return i_insset;
    }
    @Override
    public SM_SMSet R505_SM_SM() throws XtumlException {
        SM_SMSet sm_smset = new SM_SMSetImpl();
        for ( Transition transition : this ) sm_smset.add( transition.R505_SM_SM() );
        return sm_smset;
    }
    @Override
    public StateMachineStateSet R506_is_destined_to_StateMachineState() throws XtumlException {
        StateMachineStateSet statemachinestateset = new StateMachineStateSetImpl();
        for ( Transition transition : this ) statemachinestateset.add( transition.R506_is_destined_to_StateMachineState() );
        return statemachinestateset;
    }
    @Override
    public CreationTransitionSet R507_is_a_CreationTransition() throws XtumlException {
        CreationTransitionSet creationtransitionset = new CreationTransitionSetImpl();
        for ( Transition transition : this ) creationtransitionset.add( transition.R507_is_a_CreationTransition() );
        return creationtransitionset;
    }
    @Override
    public NewStateTransitionSet R507_is_a_NewStateTransition() throws XtumlException {
        NewStateTransitionSet newstatetransitionset = new NewStateTransitionSetImpl();
        for ( Transition transition : this ) newstatetransitionset.add( transition.R507_is_a_NewStateTransition() );
        return newstatetransitionset;
    }
    @Override
    public NoEventTransitionSet R507_is_a_NoEventTransition() throws XtumlException {
        NoEventTransitionSet noeventtransitionset = new NoEventTransitionSetImpl();
        for ( Transition transition : this ) noeventtransitionset.add( transition.R507_is_a_NoEventTransition() );
        return noeventtransitionset;
    }
    @Override
    public MealyActionHomeSet R512_MealyActionHome() throws XtumlException {
        MealyActionHomeSet mealyactionhomeset = new MealyActionHomeSetImpl();
        for ( Transition transition : this ) mealyactionhomeset.add( transition.R512_MealyActionHome() );
        return mealyactionhomeset;
    }
    @Override
    public TransitionActionHomeSet R530_houses_action_for_TransitionActionHome() throws XtumlException {
        TransitionActionHomeSet transitionactionhomeset = new TransitionActionHomeSetImpl();
        for ( Transition transition : this ) transitionactionhomeset.add( transition.R530_houses_action_for_TransitionActionHome() );
        return transitionactionhomeset;
    }


    @Override
    public Transition nullElement() {
        return TransitionImpl.EMPTY_TRANSITION;
    }

    @Override
    public TransitionSet emptySet() {
      return new TransitionSetImpl();
    }

    @Override
    public TransitionSet value() {
        return this;
    }

    @Override
    public List<Transition> elements() {
        return Arrays.asList(toArray(new Transition[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/statemachine/impl/TransitionSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.statemachine.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.instance.I_INSSet;
import io.ciera.tool.sql.ooaofooa.instance.impl.I_INSSetImpl;
import io.ciera.tool.sql.ooaofooa.statemachine.CreationTransitionSet;
import io.ciera.tool.sql.ooaofooa.statemachine.MealyActionHomeSet;
import io.ciera.tool.sql.ooaofooa.statemachine.NewStateTransitionSet;
import io.ciera.tool.sql.ooaofooa.statemachine.NoEventTransitionSet;
import io.ciera.tool.sql.ooaofooa.statemachine.SM_SMSet;
import io.ciera.tool.sql.ooaofooa.statemachine.StateMachineStateSet;
import io.ciera.tool.sql.ooaofooa.statemachine.Transition;
import io.ciera.tool.sql.ooaofooa.statemachine.TransitionActionHomeSet;
import io.ciera.tool.sql.ooaofooa.statemachine.TransitionSet;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.CreationTransitionSetImpl;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.MealyActionHomeSetImpl;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.NewStateTransitionSetImpl;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.NoEventTransitionSetImpl;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.SM_SMSetImpl;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.StateMachineStateSetImpl;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.TransitionActionHomeSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class TransitionSetImpl extends InstanceSet<TransitionSet,Transition> implements TransitionSet {

    public TransitionSetImpl() {
    }

    public TransitionSetImpl(Comparator<? super Transition> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setSM_ID( UniqueId ref_SM_ID ) throws XtumlException {
        for ( Transition transition : this ) transition.setSM_ID( ref_SM_ID );
    }
    @Override
    public void setTrans_ID( UniqueId m_Trans_ID ) throws XtumlException {
        for ( Transition transition : this ) transition.setTrans_ID( m_Trans_ID );
    }
    @Override
    public void setSMspd_IDdeprecated( UniqueId m_SMspd_IDdeprecated ) throws XtumlException {
        for ( Transition transition : this ) transition.setSMspd_IDdeprecated( m_SMspd_IDdeprecated );
    }
    @Override
    public void setSMstt_ID( UniqueId ref_SMstt_ID ) throws XtumlException {
        for ( Transition transition : this ) transition.setSMstt_ID( ref_SMstt_ID );
    }


    // selections
    @Override
    public I_INSSet R2953_caused_last_state_change_to_I_INS() throws XtumlException {
        I_INSSet i_insset = new I_INSSetImpl();
        for ( Transition transition : this ) i_insset.addAll( transition.R2953_caused_last_state_change_to_I_INS() );
        return i_insset;
    }
    @Override
    public SM_SMSet R505_SM_SM() throws XtumlException {
        SM_SMSet sm_smset = new SM_SMSetImpl();
        for ( Transition transition : this ) sm_smset.add( transition.R505_SM_SM() );
        return sm_smset;
    }
    @Override
    public StateMachineStateSet R506_is_destined_to_StateMachineState() throws XtumlException {
        StateMachineStateSet statemachinestateset = new StateMachineStateSetImpl();
        for ( Transition transition : this ) statemachinestateset.add( transition.R506_is_destined_to_StateMachineState() );
        return statemachinestateset;
    }
    @Override
    public CreationTransitionSet R507_is_a_CreationTransition() throws XtumlException {
        CreationTransitionSet creationtransitionset = new CreationTransitionSetImpl();
        for ( Transition transition : this ) creationtransitionset.add( transition.R507_is_a_CreationTransition() );
        return creationtransitionset;
    }
    @Override
    public NewStateTransitionSet R507_is_a_NewStateTransition() throws XtumlException {
        NewStateTransitionSet newstatetransitionset = new NewStateTransitionSetImpl();
        for ( Transition transition : this ) newstatetransitionset.add( transition.R507_is_a_NewStateTransition() );
        return newstatetransitionset;
    }
    @Override
    public NoEventTransitionSet R507_is_a_NoEventTransition() throws XtumlException {
        NoEventTransitionSet noeventtransitionset = new NoEventTransitionSetImpl();
        for ( Transition transition : this ) noeventtransitionset.add( transition.R507_is_a_NoEventTransition() );
        return noeventtransitionset;
    }
    @Override
    public MealyActionHomeSet R512_MealyActionHome() throws XtumlException {
        MealyActionHomeSet mealyactionhomeset = new MealyActionHomeSetImpl();
        for ( Transition transition : this ) mealyactionhomeset.add( transition.R512_MealyActionHome() );
        return mealyactionhomeset;
    }
    @Override
    public TransitionActionHomeSet R530_houses_action_for_TransitionActionHome() throws XtumlException {
        TransitionActionHomeSet transitionactionhomeset = new TransitionActionHomeSetImpl();
        for ( Transition transition : this ) transitionactionhomeset.add( transition.R530_houses_action_for_TransitionActionHome() );
        return transitionactionhomeset;
    }


    @Override
    public Transition nullElement() {
        return TransitionImpl.EMPTY_TRANSITION;
    }

    @Override
    public TransitionSet emptySet() {
      return new TransitionSetImpl();
    }

    @Override
    public TransitionSet emptySet(Comparator<? super Transition> comp) {
      return new TransitionSetImpl(comp);
    }

    @Override
    public TransitionSet value() {
        return this;
    }

    @Override
    public List<Transition> elements() {
        return Arrays.asList(toArray(new Transition[0]));
    }

}
